==> haskell-generic-deriving-1.12.4-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-generic-deriving.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: generic-deriving
version: 1.12.4
id: generic-deriving-1.12.4-71YnxiTGQd52ZmJZyyV5e1
key: generic-deriving-1.12.4-71YnxiTGQd52ZmJZyyV5e1
license: BSD-3-Clause
copyright: 2011-2013 Universiteit Utrecht, University of Oxford
maintainer: generics@haskell.org
author: José Pedro Magalhães
stability: experimental
homepage: https://github.com/dreixel/generic-deriving
synopsis: Generic programming library for generalised deriving.
description:
    This package provides functionality for generalising the deriving mechanism
    in Haskell to arbitrary classes. It was first described in the paper:
    .
    *  /A generic deriving mechanism for Haskell/.
    Jose Pedro Magalhaes, Atze Dijkstra, Johan Jeuring, and Andres Loeh.
    Haskell'\''10.
    .
    The current implementation integrates with the new GHC Generics. See
    <http://www.haskell.org/haskellwiki/GHC.Generics> for more information.
    Template Haskell code is provided for supporting older GHCs.
category: Generics
abi: 4b6a7af0e50bccf6e1eeace24174703d
exposed: True
exposed-modules:
    Generics.Deriving Generics.Deriving.Base Generics.Deriving.ConNames
    Generics.Deriving.Copoint Generics.Deriving.Default
    Generics.Deriving.Enum Generics.Deriving.Eq
    Generics.Deriving.Foldable Generics.Deriving.Functor
    Generics.Deriving.Instances Generics.Deriving.Monoid
    Generics.Deriving.Semigroup Generics.Deriving.Show
    Generics.Deriving.TH Generics.Deriving.Traversable
    Generics.Deriving.Uniplate
hidden-modules: Generics.Deriving.Base.Internal
                Generics.Deriving.TH.Internal Paths_generic_deriving
                Generics.Deriving.TH.Post4_9
import-dirs: /usr/lib/ghc-8.6.5/site-local/generic-deriving-1.12.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/generic-deriving-1.12.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/generic-deriving-1.12.4
hs-libraries: HSgeneric-deriving-1.12.4-71YnxiTGQd52ZmJZyyV5e1
depends:
    base-4.12.0.0 containers-0.6.0.1 ghc-prim-0.5.3
    template-haskell-2.14.0.0
    th-abstraction-0.2.11.0-DAhuCgi08HTBWsDjm9nrOq
haddock-interfaces: /usr/share/doc/haskell-generic-deriving/html/generic-deriving.haddock
haddock-html: /usr/share/doc/haskell-generic-deriving/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-deriving-1.12.4-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-generic-deriving.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: generic-deriving
version: 1.12.4
id: generic-deriving-1.12.4-9IUJTN1Ryh72XSuVeUBm5b
key: generic-deriving-1.12.4-9IUJTN1Ryh72XSuVeUBm5b
license: BSD-3-Clause
copyright: 2011-2013 Universiteit Utrecht, University of Oxford
maintainer: generics@haskell.org
author: José Pedro Magalhães
stability: experimental
homepage: https://github.com/dreixel/generic-deriving
synopsis: Generic programming library for generalised deriving.
description:
    This package provides functionality for generalising the deriving mechanism
    in Haskell to arbitrary classes. It was first described in the paper:
    .
    *  /A generic deriving mechanism for Haskell/.
    Jose Pedro Magalhaes, Atze Dijkstra, Johan Jeuring, and Andres Loeh.
    Haskell'\''10.
    .
    The current implementation integrates with the new GHC Generics. See
    <http://www.haskell.org/haskellwiki/GHC.Generics> for more information.
    Template Haskell code is provided for supporting older GHCs.
category: Generics
abi: 37bd72d386b71be8d42822a5dbae9d22
exposed: True
exposed-modules:
    Generics.Deriving Generics.Deriving.Base Generics.Deriving.ConNames
    Generics.Deriving.Copoint Generics.Deriving.Default
    Generics.Deriving.Enum Generics.Deriving.Eq
    Generics.Deriving.Foldable Generics.Deriving.Functor
    Generics.Deriving.Instances Generics.Deriving.Monoid
    Generics.Deriving.Semigroup Generics.Deriving.Show
    Generics.Deriving.TH Generics.Deriving.Traversable
    Generics.Deriving.Uniplate
hidden-modules: Generics.Deriving.Base.Internal
                Generics.Deriving.TH.Internal Paths_generic_deriving
                Generics.Deriving.TH.Post4_9
import-dirs: /usr/lib/ghc-8.6.5/site-local/generic-deriving-1.12.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/generic-deriving-1.12.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/generic-deriving-1.12.4
hs-libraries: HSgeneric-deriving-1.12.4-9IUJTN1Ryh72XSuVeUBm5b
depends:
    base-4.12.0.0 containers-0.6.0.1 ghc-prim-0.5.3
    template-haskell-2.14.0.0
    th-abstraction-0.2.11.0-DAhuCgi08HTBWsDjm9nrOq
haddock-interfaces: /usr/share/doc/haskell-generic-deriving/html/generic-deriving.haddock
haddock-html: /usr/share/doc/haskell-generic-deriving/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
